Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
parent: &str,
) -> anyhow::Result<()> {
let client = Instances::builder().build().await?;
let mut list = client.list_instances()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Concrete implementations of this client library traits.
Structs
- Applications
- Implements a client for the App Engine Admin API.
- Authorized
Certificates - Implements a client for the App Engine Admin API.
- Authorized
Domains - Implements a client for the App Engine Admin API.
- Domain
Mappings - Implements a client for the App Engine Admin API.
- Firewall
- Implements a client for the App Engine Admin API.
- Instances
- Implements a client for the App Engine Admin API.
- Services
- Implements a client for the App Engine Admin API.
- Versions
- Implements a client for the App Engine Admin API.