pub struct AuthorizedCertificates { /* private fields */ }Expand description
Implements a client for the App Engine Admin API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = AuthorizedCertificates::builder().build().await?;
let mut list = client.list_authorized_certificates()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Manages SSL certificates a user is authorized to administer. A user can administer any SSL certificates applicable to their authorized domains.
Configuration
To configure AuthorizedCertificates use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://appengine.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
AuthorizedCertificates holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap AuthorizedCertificates in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl AuthorizedCertificates
impl AuthorizedCertificates
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for AuthorizedCertificates.
let client = AuthorizedCertificates::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: AuthorizedCertificates + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: AuthorizedCertificates + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Lists all SSL certificates the user is authorized to administer.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_appengine_v1::Result;
async fn sample(
client: &AuthorizedCertificates
) -> Result<()> {
let mut list = client.list_authorized_certificates()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Gets the specified SSL certificate.
Example
use google_cloud_appengine_v1::Result;
async fn sample(
client: &AuthorizedCertificates
) -> Result<()> {
let response = client.get_authorized_certificate()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Uploads the specified SSL certificate.
Example
use google_cloud_appengine_v1::Result;
async fn sample(
client: &AuthorizedCertificates
) -> Result<()> {
let response = client.create_authorized_certificate()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Updates the specified SSL certificate. To renew a certificate and maintain
its existing domain mappings, update certificate_data with a new
certificate. The new certificate must be applicable to the same domains as
the original certificate. The certificate display_name may also be
updated.
Example
use google_cloud_appengine_v1::Result;
async fn sample(
client: &AuthorizedCertificates
) -> Result<()> {
let response = client.update_authorized_certificate()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Deletes the specified SSL certificate.
Example
use google_cloud_appengine_v1::Result;
async fn sample(
client: &AuthorizedCertificates
) -> Result<()> {
client.delete_authorized_certificate()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_appengine_v1::Result;
async fn sample(
client: &AuthorizedCertificates
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_appengine_v1::Result;
async fn sample(
client: &AuthorizedCertificates
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for AuthorizedCertificates
impl Clone for AuthorizedCertificates
Sourcefn clone(&self) -> AuthorizedCertificates
fn clone(&self) -> AuthorizedCertificates
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more