pub struct AuthorizedDomains { /* private fields */ }Expand description
Implements a client for the App Engine Admin API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = AuthorizedDomains::builder().build().await?;
let mut list = client.list_authorized_domains()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Manages domains a user is authorized to administer. To authorize use of a domain, verify ownership via Webmaster Central.
Configuration
To configure AuthorizedDomains use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://appengine.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
AuthorizedDomains holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap AuthorizedDomains in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl AuthorizedDomains
impl AuthorizedDomains
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for AuthorizedDomains.
let client = AuthorizedDomains::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: AuthorizedDomains + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: AuthorizedDomains + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Lists all domains the user is authorized to administer.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_appengine_v1::Result;
async fn sample(
client: &AuthorizedDomains
) -> Result<()> {
let mut list = client.list_authorized_domains()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_appengine_v1::Result;
async fn sample(
client: &AuthorizedDomains
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_appengine_v1::Result;
async fn sample(
client: &AuthorizedDomains
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for AuthorizedDomains
impl Clone for AuthorizedDomains
Sourcefn clone(&self) -> AuthorizedDomains
fn clone(&self) -> AuthorizedDomains
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more