pub struct Instances { /* private fields */ }Expand description
Implements a client for the App Engine Admin API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = Instances::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_instances()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Manages instances of a version.
Configuration
To configure Instances use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://appengine.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
Instances holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap Instances in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl Instances
impl Instances
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for Instances.
let client = Instances::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: Instances + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: Instances + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_instances(&self) -> ListInstances
pub fn list_instances(&self) -> ListInstances
Lists the instances of a version.
Tip: To aggregate details about instances over time, see the Stackdriver Monitoring API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_appengine_v1::Result;
async fn sample(
client: &Instances, parent: &str
) -> Result<()> {
let mut list = client.list_instances()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_instance(&self) -> GetInstance
pub fn get_instance(&self) -> GetInstance
Gets instance information.
Example
use google_cloud_appengine_v1::Result;
async fn sample(
client: &Instances
) -> Result<()> {
let response = client.get_instance()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_instance(&self) -> DeleteInstance
pub fn delete_instance(&self) -> DeleteInstance
Stops a running instance.
The instance might be automatically recreated based on the scaling settings of the version. For more information, see “How Instances are Managed” (standard environment | flexible environment).
To ensure that instances are not re-created and avoid getting billed, you
can stop all instances within the target version by changing the serving
status of the version to STOPPED with the
apps.services.versions.patch
method.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_appengine_v1::Result;
async fn sample(
client: &Instances
) -> Result<()> {
client.delete_instance()
/* set fields */
.poller().until_done().await?;
Ok(())
}Sourcepub fn debug_instance(&self) -> DebugInstance
pub fn debug_instance(&self) -> DebugInstance
Enables debugging on a VM instance. This allows you to use the SSH command to connect to the virtual machine where the instance lives. While in “debug mode”, the instance continues to serve live traffic. You should delete the instance when you are done debugging and then allow the system to take over and determine if another instance should be started.
Only applicable for instances in App Engine flexible environment.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_appengine_v1::Result;
async fn sample(
client: &Instances
) -> Result<()> {
let response = client.debug_instance()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_appengine_v1::Result;
async fn sample(
client: &Instances
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_appengine_v1::Result;
async fn sample(
client: &Instances
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}