pub struct Services { /* private fields */ }Expand description
Implements a client for the App Engine Admin API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = Services::builder().build().await?;
let mut list = client.list_services()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Manages services of an application.
Configuration
To configure Services use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://appengine.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
Services holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap Services in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl Services
impl Services
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for Services.
let client = Services::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: Services + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: Services + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_services(&self) -> ListServices
pub fn list_services(&self) -> ListServices
Lists all the services in the application.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_appengine_v1::Result;
async fn sample(
client: &Services
) -> Result<()> {
let mut list = client.list_services()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_service(&self) -> GetService
pub fn get_service(&self) -> GetService
Gets the current configuration of the specified service.
Example
use google_cloud_appengine_v1::Result;
async fn sample(
client: &Services
) -> Result<()> {
let response = client.get_service()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_service(&self) -> UpdateService
pub fn update_service(&self) -> UpdateService
Updates the configuration of the specified service.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_appengine_v1::Result;
async fn sample(
client: &Services
) -> Result<()> {
let response = client.update_service()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_service(&self) -> DeleteService
pub fn delete_service(&self) -> DeleteService
Deletes the specified service and all enclosed versions.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_appengine_v1::Result;
async fn sample(
client: &Services
) -> Result<()> {
client.delete_service()
/* set fields */
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_appengine_v1::Result;
async fn sample(
client: &Services
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_appengine_v1::Result;
async fn sample(
client: &Services
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}