#[non_exhaustive]pub enum AuthFailAction {
Unspecified,
Redirect,
Unauthorized,
UnknownValue(UnknownValue),
}Expand description
Actions to take when the user is not logged in.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Not specified. AUTH_FAIL_ACTION_REDIRECT is assumed.
Redirect
Redirects user to “accounts.google.com”. The user is redirected back to the application URL after signing in or creating an account.
Rejects request with a 401 HTTP status code and an error
message.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using AuthFailAction::value or AuthFailAction::name.
Implementations