#[non_exhaustive]pub enum AuthorizedCertificateView {
BasicCertificate,
FullCertificate,
UnknownValue(UnknownValue),
}Expand description
Fields that should be returned when an AuthorizedCertificate resource is retrieved.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BasicCertificate
Basic certificate information, including applicable domains and expiration date.
FullCertificate
The information from BASIC_CERTIFICATE, plus detailed information on the
domain mappings that have this certificate mapped.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using AuthorizedCertificateView::value or AuthorizedCertificateView::name.
Implementations