#[non_exhaustive]pub enum LoginRequirement {
LoginUnspecified,
LoginOptional,
LoginAdmin,
LoginRequired,
UnknownValue(UnknownValue),
}Expand description
Methods to restrict access to a URL based on login status.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
LoginUnspecified
Not specified. LOGIN_OPTIONAL is assumed.
LoginOptional
Does not require that the user is signed in.
LoginAdmin
If the user is not signed in, the auth_fail_action is taken.
In addition, if the user is not an administrator for the
application, they are given an error message regardless of
auth_fail_action. If the user is an administrator, the handler
proceeds.
LoginRequired
If the user has signed in, the handler proceeds normally. Otherwise, the auth_fail_action is taken.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using LoginRequirement::value or LoginRequirement::name.
Implementations