#[non_exhaustive]pub struct OperationMetadataV1 {
pub method: String,
pub insert_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub user: String,
pub target: String,
pub ephemeral_message: String,
pub warning: Vec<String>,
pub method_metadata: Option<MethodMetadata>,
/* private fields */
}Expand description
Metadata for the given google.longrunning.Operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.method: StringAPI method that initiated this operation. Example:
google.appengine.v1.Versions.CreateVersion.
@OutputOnly
insert_time: Option<Timestamp>Time that this operation was created.
@OutputOnly
end_time: Option<Timestamp>Time that this operation completed.
@OutputOnly
user: StringUser who requested this operation.
@OutputOnly
target: StringName of the resource that this operation is acting on. Example:
apps/myapp/services/default.
@OutputOnly
ephemeral_message: StringEphemeral message that may change every time the operation is polled. @OutputOnly
warning: Vec<String>Durable messages that persist on every operation poll. @OutputOnly
method_metadata: Option<MethodMetadata>Metadata specific to the type of operation in progress. @OutputOnly
Implementations
Sourceimpl OperationMetadataV1
impl OperationMetadataV1
Sourcepub fn set_method<T: Into<String>>(self, v: T) -> Self
pub fn set_method<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_insert_time<T>(self, v: T) -> Self
pub fn set_insert_time<T>(self, v: T) -> Self
Sets the value of insert_time.
Example
use wkt::Timestamp;
let x = OperationMetadataV1::new().set_insert_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_insert_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_insert_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of insert_time.
Example
use wkt::Timestamp;
let x = OperationMetadataV1::new().set_or_clear_insert_time(Some(Timestamp::default()/* use setters */));
let x = OperationMetadataV1::new().set_or_clear_insert_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_target<T: Into<String>>(self, v: T) -> Self
pub fn set_target<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_ephemeral_message<T: Into<String>>(self, v: T) -> Self
pub fn set_ephemeral_message<T: Into<String>>(self, v: T) -> Self
Sets the value of ephemeral_message.
Example
let x = OperationMetadataV1::new().set_ephemeral_message("example");Sourcepub fn set_warning<T, V>(self, v: T) -> Self
pub fn set_warning<T, V>(self, v: T) -> Self
Sourcepub fn set_method_metadata<T: Into<Option<MethodMetadata>>>(self, v: T) -> Self
pub fn set_method_metadata<T: Into<Option<MethodMetadata>>>(self, v: T) -> Self
Sets the value of method_metadata.
Note that all the setters affecting method_metadata are mutually
exclusive.
Example
use google_cloud_appengine_v1::model::CreateVersionMetadataV1;
let x = OperationMetadataV1::new().set_method_metadata(Some(
google_cloud_appengine_v1::model::operation_metadata_v_1::MethodMetadata::CreateVersionMetadata(CreateVersionMetadataV1::default().into())));Sourcepub fn create_version_metadata(&self) -> Option<&Box<CreateVersionMetadataV1>>
pub fn create_version_metadata(&self) -> Option<&Box<CreateVersionMetadataV1>>
The value of method_metadata
if it holds a CreateVersionMetadata, None if the field is not set or
holds a different branch.
Sourcepub fn set_create_version_metadata<T: Into<Box<CreateVersionMetadataV1>>>(
self,
v: T,
) -> Self
pub fn set_create_version_metadata<T: Into<Box<CreateVersionMetadataV1>>>( self, v: T, ) -> Self
Sets the value of method_metadata
to hold a CreateVersionMetadata.
Note that all the setters affecting method_metadata are
mutually exclusive.
Example
use google_cloud_appengine_v1::model::CreateVersionMetadataV1;
let x = OperationMetadataV1::new().set_create_version_metadata(CreateVersionMetadataV1::default()/* use setters */);
assert!(x.create_version_metadata().is_some());Trait Implementations
Sourceimpl Clone for OperationMetadataV1
impl Clone for OperationMetadataV1
Sourcefn clone(&self) -> OperationMetadataV1
fn clone(&self) -> OperationMetadataV1
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for OperationMetadataV1
impl Debug for OperationMetadataV1
Sourceimpl Default for OperationMetadataV1
impl Default for OperationMetadataV1
Sourcefn default() -> OperationMetadataV1
fn default() -> OperationMetadataV1
Sourceimpl Message for OperationMetadataV1
impl Message for OperationMetadataV1
Sourceimpl PartialEq for OperationMetadataV1
impl PartialEq for OperationMetadataV1
impl StructuralPartialEq for OperationMetadataV1