Module client

Module client 

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = Instances::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_instances()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Concrete implementations of this client library traits.

Structs

Applications
Implements a client for the App Engine Admin API.
AuthorizedCertificates
Implements a client for the App Engine Admin API.
AuthorizedDomains
Implements a client for the App Engine Admin API.
DomainMappings
Implements a client for the App Engine Admin API.
Firewall
Implements a client for the App Engine Admin API.
Instances
Implements a client for the App Engine Admin API.
Services
Implements a client for the App Engine Admin API.
Versions
Implements a client for the App Engine Admin API.